==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/RawIptablesFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RawIptablesFluent<A extends RawIptablesFluent<A>> extends BaseFluent<A>{
  public RawIptablesFluent() {
  }
  
  public RawIptablesFluent(RawIptables instance) {
    this.copyInstance(instance);
  }
  private String device;
  private String direction;
  private List<String> ipsets = new ArrayList<String>();
  private String name;
  private String source;
  
  protected void copyInstance(RawIptables instance) {
    instance = (instance != null ? instance : new RawIptables());
  
    if (instance != null) {
        this.withDevice(instance.getDevice());
        this.withDirection(instance.getDirection());
        this.withIpsets(instance.getIpsets());
        this.withName(instance.getName());
        this.withSource(instance.getSource());
        this.withDevice(instance.getDevice());
        this.withDirection(instance.getDirection());
        this.withIpsets(instance.getIpsets());
        this.withName(instance.getName());
        this.withSource(instance.getSource());
      }
  }
  
  public String getDevice() {
    return this.device;
  }
  
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  
  public boolean hasDevice() {
    return this.device != null;
  }
  
  public String getDirection() {
    return this.direction;
  }
  
  public A withDirection(String direction) {
    this.direction=direction; return (A) this;
  }
  
  public boolean hasDirection() {
    return this.direction != null;
  }
  
  public A addToIpsets(int index,String item) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    this.ipsets.add(index, item);
    return (A)this;
  }
  
  public A setToIpsets(int index,String item) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    this.ipsets.set(index, item); return (A)this;
  }
  
  public A addToIpsets(java.lang.String... items) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    for (String item : items) {this.ipsets.add(item);} return (A)this;
  }
  
  public A addAllToIpsets(Collection<String> items) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    for (String item : items) {this.ipsets.add(item);} return (A)this;
  }
  
  public A removeFromIpsets(java.lang.String... items) {
    if (this.ipsets == null) return (A)this;
    for (String item : items) { this.ipsets.remove(item);} return (A)this;
  }
  
  public A removeAllFromIpsets(Collection<String> items) {
    if (this.ipsets == null) return (A)this;
    for (String item : items) { this.ipsets.remove(item);} return (A)this;
  }
  
  public List<String> getIpsets() {
    return this.ipsets;
  }
  
  public String getIpset(int index) {
    return this.ipsets.get(index);
  }
  
  public String getFirstIpset() {
    return this.ipsets.get(0);
  }
  
  public String getLastIpset() {
    return this.ipsets.get(ipsets.size() - 1);
  }
  
  public String getMatchingIpset(Predicate<String> predicate) {
    for (String item: ipsets) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingIpset(Predicate<String> predicate) {
    for (String item: ipsets) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withIpsets(List<String> ipsets) {
    if (ipsets != null) {this.ipsets = new ArrayList(); for (String item : ipsets){this.addToIpsets(item);}} else { this.ipsets = null;} return (A) this;
  }
  
  public A withIpsets(java.lang.String... ipsets) {
    if (this.ipsets != null) {this.ipsets.clear(); _visitables.remove("ipsets"); }
    if (ipsets != null) {for (String item :ipsets){ this.addToIpsets(item);}} return (A) this;
  }
  
  public boolean hasIpsets() {
    return ipsets != null && !ipsets.isEmpty();
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getSource() {
    return this.source;
  }
  
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  
  public boolean hasSource() {
    return this.source != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RawIptablesFluent that = (RawIptablesFluent) o;
    if (!java.util.Objects.equals(device, that.device)) return false;
  
    if (!java.util.Objects.equals(direction, that.direction)) return false;
  
    if (!java.util.Objects.equals(ipsets, that.ipsets)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(source, that.source)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(device,  direction,  ipsets,  name,  source,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (direction != null) { sb.append("direction:"); sb.append(direction + ","); }
    if (ipsets != null && !ipsets.isEmpty()) { sb.append("ipsets:"); sb.append(ipsets + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/RawIptablesFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RawIptablesFluent<A extends RawIptablesFluent<A>> extends BaseFluent<A>{
  public RawIptablesFluent() {
  }
  
  public RawIptablesFluent(RawIptables instance) {
    this.copyInstance(instance);
  }
  private String device;
  private String direction;
  private List<String> ipsets = new ArrayList<String>();
  private String name;
  private String source;
  
  protected void copyInstance(RawIptables instance) {
    instance = (instance != null ? instance : new RawIptables());
    if (instance != null) {
          this.withDevice(instance.getDevice());
          this.withDirection(instance.getDirection());
          this.withIpsets(instance.getIpsets());
          this.withName(instance.getName());
          this.withSource(instance.getSource());
          this.withDevice(instance.getDevice());
          this.withDirection(instance.getDirection());
          this.withIpsets(instance.getIpsets());
          this.withName(instance.getName());
          this.withSource(instance.getSource());
        }
  }
  
  public String getDevice() {
    return this.device;
  }
  
  public A withDevice(String device) {
    this.device = device;
    return (A) this;
  }
  
  public boolean hasDevice() {
    return this.device != null;
  }
  
  public String getDirection() {
    return this.direction;
  }
  
  public A withDirection(String direction) {
    this.direction = direction;
    return (A) this;
  }
  
  public boolean hasDirection() {
    return this.direction != null;
  }
  
  public A addToIpsets(int index,String item) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    this.ipsets.add(index, item);
    return (A)this;
  }
  
  public A setToIpsets(int index,String item) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    this.ipsets.set(index, item); return (A)this;
  }
  
  public A addToIpsets(java.lang.String... items) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    for (String item : items) {this.ipsets.add(item);} return (A)this;
  }
  
  public A addAllToIpsets(Collection<String> items) {
    if (this.ipsets == null) {this.ipsets = new ArrayList<String>();}
    for (String item : items) {this.ipsets.add(item);} return (A)this;
  }
  
  public A removeFromIpsets(java.lang.String... items) {
    if (this.ipsets == null) return (A)this;
    for (String item : items) { this.ipsets.remove(item);} return (A)this;
  }
  
  public A removeAllFromIpsets(Collection<String> items) {
    if (this.ipsets == null) return (A)this;
    for (String item : items) { this.ipsets.remove(item);} return (A)this;
  }
  
  public List<String> getIpsets() {
    return this.ipsets;
  }
  
  public String getIpset(int index) {
    return this.ipsets.get(index);
  }
  
  public String getFirstIpset() {
    return this.ipsets.get(0);
  }
  
  public String getLastIpset() {
    return this.ipsets.get(ipsets.size() - 1);
  }
  
  public String getMatchingIpset(Predicate<String> predicate) {
      for (String item : ipsets) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingIpset(Predicate<String> predicate) {
      for (String item : ipsets) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withIpsets(List<String> ipsets) {
    if (ipsets != null) {
        this.ipsets = new ArrayList();
        for (String item : ipsets) {
          this.addToIpsets(item);
        }
    } else {
      this.ipsets = null;
    }
    return (A) this;
  }
  
  public A withIpsets(java.lang.String... ipsets) {
    if (this.ipsets != null) {this.ipsets.clear(); _visitables.remove("ipsets"); }
    if (ipsets != null) {for (String item :ipsets){ this.addToIpsets(item);}} return (A) this;
  }
  
  public boolean hasIpsets() {
    return this.ipsets != null && !this.ipsets.isEmpty();
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getSource() {
    return this.source;
  }
  
  public A withSource(String source) {
    this.source = source;
    return (A) this;
  }
  
  public boolean hasSource() {
    return this.source != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RawIptablesFluent that = (RawIptablesFluent) o;
    if (!java.util.Objects.equals(device, that.device)) return false;
    if (!java.util.Objects.equals(direction, that.direction)) return false;
    if (!java.util.Objects.equals(ipsets, that.ipsets)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(source, that.source)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(device,  direction,  ipsets,  name,  source,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (direction != null) { sb.append("direction:"); sb.append(direction + ","); }
    if (ipsets != null && !ipsets.isEmpty()) { sb.append("ipsets:"); sb.append(ipsets + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  

}
